@@ -3,10 +3,8 @@ import json
 import os
 import pathlib
 import re
-import warnings
 from datetime import datetime
 from io import StringIO
-from xml.dom.minidom import parseString
 from xml.sax import make_parser
 from xml.sax.handler import ContentHandler
 
@@ -22,9 +20,8 @@ from esi_utils_rupture.origin import Origin, write_event_file
 from shakemap_modules.coremods.dyfi import _get_dyfi_dataframe
 from shakemap_modules.coremods.sm_select import SelectModule
 from shakemap_modules.utils.comcat import get_bytes
-from shakemap_modules.utils.config import get_config_paths
 from shakemap_modules.utils.dataframe import dataframe_to_xml
-from shakemap_modules.utils.utils import get_network_name, migrate_gmpe, set_gmpe
+from shakemap_modules.utils.utils import get_network_name
 
 EVENT_URL_TEMPLATE = (
     "https://earthquake.usgs.gov/earthquakes/feed/v1.0/detail/{eventid}.geojson"
@@ -40,15 +37,7 @@ CATALOGS_URL = "https://earthquake.usgs.gov/fdsnws/event/1/catalogs"
 DEFAULT_MIN_RESP = 3
 
 
-def get_matching_catalog(eventid):
-    response = requests.get(CATALOGS_URL)
-    root = parseString(response.text)
-    catalog_els = root.getElementsByTagName("Catalog")
-    for element in catalog_els:
-        tag = element.firstChild.data
-        if eventid.startswith(tag):
-            return tag
-    return None
+DEFAULT_SOURCE_PREFERENCES = ["atlas", "us"]
 
 
 class ShakeClone:
@@ -62,8 +51,7 @@ class ShakeClone:
     ):
         os.environ["CALLED_FROM_MAIN"] = "True"
         self.source = source
-        if source is None:
-            self.source = get_matching_catalog(eventid)
+
         self.eventid = eventid
         self.event_path = pathlib.Path(event_path)
         if not self.event_path.is_dir():
@@ -87,10 +75,19 @@ class ShakeClone:
                     "shakemap-scenario"
                 ]
             sources = [shakemap["source"] for shakemap in shakemaps]
-            if self.source in sources:
-                idx = sources.index(self.source)
+            idx = 0
+            if self.source is not None:
+                if self.source in sources:
+                    idx = sources.index(self.source)
+                else:
+                    raise KeyError(
+                        f"Source {self.source} not in list of available ShakeMap sources: {sources}"
+                    )
             else:
-                idx = 0
+                for prefsource in DEFAULT_SOURCE_PREFERENCES:
+                    if prefsource in sources:
+                        idx = sources.index(prefsource)
+
             self.shakemap = shakemaps[idx]
         self.event_dict = event_dict
         if event_dict is None:
@@ -532,7 +529,6 @@ def get_instrumented(data_file):
 
     cursor.execute("SELECT count(*) FROM station")
     nrows = cursor.fetchone()[0]
-    instrument_file = None
     instrumented_json = None
     if nrows:
         instrumented_json = instrumented.getGeoJson()
